@@ -3,7 +3,7 @@
 '''
 A library to access Tryton's models like a client.
 '''
-__version__ = "2.8.2"
+__version__ = "3.0.1"
 __all__ = ['Model', 'Wizard']
 import sys
 try:
@@ -355,6 +355,7 @@ class MetaModelFactory(object):
         'reference': ReferenceDescriptor,
         'date': DateDescriptor,
         'datetime': DateTimeDescriptor,
+        'timestamp': DateTimeDescriptor,
         'time': TimeDescriptor,
         'dict': DictDescriptor,
         'many2one': Many2OneDescriptor,
@@ -634,7 +635,8 @@ class Model(object):
     def __cmp__(self, other):
         'Compare with other'
         if isinstance(other, Model):
-            return cmp(self.id, other.id)
+            return cmp((self.__class__.__name__, self.id),
+                (other.__class__.__name__, other.id))
         if isinstance(other, (bool, NoneType)):
             return 1
         raise NotImplementedError
@@ -793,7 +795,7 @@ class Model(object):
             for record in to_remove:
                 # remove without signal
                 list.remove(getattr(self, field), record)
-            if value and (value.get('add') or value.get('update')):
+            if value and value.get('add') or value.get('update'):
                 for vals in value.get('add', []):
                     relation = Model.get(self._fields[field]['relation'],
                             self._config)
